@@ -3,7 +3,7 @@ package Promise::ES6;
 use strict;
 use warnings;
 
-our $VERSION = '0.08';
+our $VERSION = '0.08_01';
 
 use constant {
 
@@ -134,12 +134,6 @@ Promise::ES6’s distinguishing features are simplicity and lightness.
 By design, it implements B<just> the standard Promise API and doesn’t
 assume you use, e.g., L<AnyEvent>.
 
-=head1 LICENSE & COPYRIGHT
-
-Copyright 2019 Gasper Software Consulting.
-
-This library is licensed under the same terms as Perl itself.
-
 =cut
 
 our $DETECT_MEMORY_LEAKS;
@@ -217,8 +211,6 @@ sub _propagate_if_needed {
 
             # It may not be necessary to empty out @$children_ar, but
             # let’s do so anyway so Perl will delete references ASAP.
-            # It’s safe to do so because from here on $value_sr is
-            # no longer a pending value.
             for my $subpromise (splice @$children_ar) {
                 $subpromise->_finish($value_sr);
             }
@@ -241,7 +233,7 @@ sub then {
         _value_sr => $value_sr,
         _children => [],
 
-        _on_finish => [ $on_resolve, $on_reject ],
+        _when_parent_completes => [ $on_resolve, $on_reject ],
 
         _detect_leak => $DETECT_MEMORY_LEAKS,
     };
@@ -277,13 +269,7 @@ sub _finish {
 
     local $@;
 
-    # A promise that new() created won’t have on-finish callbacks,
-    # but a promise that came from then/catch/finally will.
-    # It’s a good idea to delete _on_finish in order to trigger garbage
-    # collection as soon and as reliably as possible. It’s safe to do so
-    # because _finish() is only called once.
-    my $callback = delete $self->{'_on_finish'};
-
+    my $callback = delete $self->{'_when_parent_completes'};
     $callback &&= $callback->[ $value_sr->isa( _REJECTION_CLASS() ) ? 1 : 0 ];
 
     # Only needed when catching, but the check would be more expensive
